#ifndef __CA_ERRNO_H
#define __CA_ERRNO_H

////////////////////////////////////////////////////////////////////////
//
// Name:	CA_errno.h
//
// Purpose:	Copycat of the features of the standard "errno" utilities.
//
////////////////////////////////////////////////////////////////////////

extern int CA_errno;

#define CUNKNWN	0	// Unknown error
#define CNOMODL	1	// Missing required model parameter
#define CINVITE	2	// Invalid iteration parameter
#define CINVCOL 3 	// Invalid column parameter
#define CINVROW 4 	// Invalid row parameter
#define CINVMDL 5	// Invalid model parameter
#define CECOUNT	CINVMDL+1



/////////////////////////////////////////////////////////////////////////
//			CA_strerror()
//
//  Return pointer to implementation-defined string corresponding
//  to CA error n.
//
//  INPUT PARAMETERS:
//	n		implementation-defined CA error number
//	
//  OUTPUT PARAMETERS:
//	None
//
//  RETURN VALUE:
//	pointer to implementation-defined string
//
/////////////////////////////////////////////////////////////////////////
char *
CA_strerror(
	const int	n);	//	IN




///////////////////////////////////////////////////////////////////////
//			CA_perror()
//
//  Prints s and an implementation-defined error message
//  corresponding to the integer in CA_errno.
//
//  INPUT PARAMETERS:
//	s		string prepended to error message
//	
//  OUTPUT PARAMETERS:
//	None
//
//  RETURN VALUE:
//	void
//
///////////////////////////////////////////////////////////////////////
void
CA_perror(
	const char	*s);	//	IN


#endif // __CA_ERRNO_H
