#ifndef __CELLULARAUTOMATA2D_H
#define __CELLULARAUTOMATA2D_H

/////////////////////////////////////////////////////////////////////////
//
// Name:	CellularAutomata2D.h
//
// Purpose:	Abstract base class for 2-dimensional lattice
//			cellular automata models.
//
/////////////////////////////////////////////////////////////////////////

#include <stdlib.h>
#include "CellularAutomata.h"
#include "Iteration.h"
#include "Dimension.h"
#include "Lattice2DTemplate.h"
#include "BinaryCell.h"


class CellularAutomata2D : public CellularAutomata {

friend ostream& operator<<(ostream&, const CellularAutomata2D&);

public:

	//
	// Default constructor
	//
	CellularAutomata2D(
	const Iteration_t& i=DEFAULT_ITERATIONS,
	const Dimension_t& r=DEFAULT_DIMENSION,
	const Dimension_t& c=DEFAULT_DIMENSION) :
		CellularAutomata(i)
		{
			latticeArr = new Lattice2DTemplate<BinaryCell>[LATTICE_COUNT];
			for (register int j=0; j<LATTICE_COUNT; j++) {
				latticeArr[j].SetDimensions(r, c);
			}
		}


	//
	// Copy constructor
	//
	CellularAutomata2D(
	const CellularAutomata2D& C) :
		CellularAutomata(C),
		latticeArr(new Lattice2DTemplate<BinaryCell>[LATTICE_COUNT])
			{
				for (register int j=0; j<LATTICE_COUNT; j++) {
					latticeArr[j] = C.latticeArr[j];
				}
			}


	//
	// Overloaded assignment operator
	//
	CellularAutomata2D&
	operator=(
	const CellularAutomata2D& C)
		{
			if (this != &C) {
				delete this;
				CellularAutomata::operator=(C);
				latticeArr = new Lattice2DTemplate<BinaryCell>[LATTICE_COUNT];
				for (register int i=0; i<LATTICE_COUNT; i++) {
					latticeArr[i] = C.latticeArr[i];
				}
			}
			return *this;
		}


	//
	// Destructor
	//
	~CellularAutomata2D()
		{ delete[] latticeArr; }


	//
	//	Makes a raw input data file for use by gnuplot. This
	//	raw data describes the current contents in the 2D
	//	lattice.
	//
	void
	PlotData()	const;


	//
	// Access functions
	//

	Dimension_t Rows()		const { return latticeArr[curr].Rows();		}
	Dimension_t Columns()	const { return latticeArr[curr].Columns();	}

protected:

	Lattice2DTemplate<BinaryCell>	*latticeArr;
								// Need two 2D lattices - one to hold
								// data from previous iteration;
								// one for the current iteration

private:

};


#endif // __CELLULARAUTOMATA2D_H
