#ifndef __CRYSTALLIZATION2D_H
#define __CRYSTALLIZATION2D_H

/////////////////////////////////////////////////////////////////////////
//
// Name:	Crystallization2D.h
//
// Purpose:	Abstract base class for 2-dimensional crystallization
//			cellular automata models.
//
/////////////////////////////////////////////////////////////////////////

#include "CellularAutomata2D.h"


class Crystallization2D : public CellularAutomata2D {

public:

	//
	// Default constructor
	//
	Crystallization2D(
	const Iteration_t& i=DEFAULT_ITERATIONS,
	const Dimension_t& r=DEFAULT_DIMENSION,
	const Dimension_t& c=DEFAULT_DIMENSION) :
		CellularAutomata2D(i, r, c)
			{ Seed(r/2, c/2); }


	//
	// Copy constructor
	//
	Crystallization2D(
	const Crystallization2D& C) :
		CellularAutomata2D(C) {}


	//
	// Overloaded assignment operator
	//
	Crystallization2D& operator=(
	const Crystallization2D& C)
		{
			if (this != &C) {
				delete this;
				CellularAutomata2D::operator=(C);
			}
			return *this;
		}


	//
	// Destructor
	//
	~Crystallization2D() {}


	//
	// Points of initiation for crystallization
	//
	void
	Seed(
	const Dimension_t&	i,
	const Dimension_t&	j)
		{
			if (latticeArr) {
				latticeArr[curr](i, j).SetState(BinaryCell::ALIVE);
			}
		}

protected:

private:

};

#endif // __CRYSTALLIZATION2D_H
