#ifndef __DETERMINISTICCRYSTALLIZATION_H
#define __DETERMINISTICCRYSTALLIZATION_H

/////////////////////////////////////////////////////////////////////////
//
// Name:	DeterministicCrystallization.h
//
// Purpose:	Deterministic cellular automata crystallization
//
/////////////////////////////////////////////////////////////////////////

#include "Crystallization2D.h"


class DeterministicCrystallization : public Crystallization2D {

public:

	//
	// Default constructor
	//
	DeterministicCrystallization(
	const Iteration_t& i=DEFAULT_ITERATIONS,
	const Dimension_t& r=DEFAULT_DIMENSION,
	const Dimension_t& c=DEFAULT_DIMENSION) :
		Crystallization2D(i, r, c) {}


	//
	// Copy constructor
	//
	DeterministicCrystallization(
	const DeterministicCrystallization& C) :
		Crystallization2D(C) {}


	//
	// Overloaded assignment operator
	//
	DeterministicCrystallization& operator=(
	const DeterministicCrystallization& C)
		{
			if (this != &C) {
				delete this;
				Crystallization2D::operator=(C);
			}
			return *this;
		}


	//
	// Destructor
	//
	~DeterministicCrystallization() {}


	//
	// This member function is still under construction. It exists,
	// but it doesn't do anything interesting.
	//
	Status_t
	ApplyRules()
		{
			SwapLattices();
			return SUCCESS;
		}


protected:

private:

};

#endif // __DETERMINISTICCRYSTALLIZATION_H
