#ifndef __LATTICEINDEX_H
#define __LATTICEINDEX_H

/////////////////////////////////////////////////////////////////////////
//
// Name:	LatticeIndex.h
//
// Purpose:	Contains definition(s) for CA simulation lattice indices.
//
/////////////////////////////////////////////////////////////////////////


/************************************************************************

	Cellular automata simulation requires that the state of all cells
	at time t be updated by applying the particular rules to each cell
	and that cell's neighborhood at time t-1. Thus, some means must be
	taken to preserve the states of all cells in the lattice at time t-1,
	rather than overwriting them with the states for time t. Some options
	for doing this might be:

	1. Parallel-processing to compute the state of each lattice cell
	simultaneously.

	2. Define the cells such that they contain two states: previous
	and current.

	3. Use two distinct lattices: one containing the previous cell
	states, and one containing the current cell states.

	This application shall employ option 3. This file contains
	declarations in support of this design.

**************************************************************************/


enum LatticeIndex_t {
	INDEX_1, INDEX_2,	// Dummy enumerations to bound/define possible
						// indices for an array of 2 (previous + current)
						// lattices. 
	LATTICE_COUNT		// Total number of lattices for the simulation (=2)
};

#endif // __LATTICEINDEX_H
